@@ -40,6 +40,7 @@
 #'
 plotLoadings <- function(spectra, pca, loads = c(1), ref = 1, ...) {
   .chkArgs(mode = 12L)
+  chkSpectra(spectra)
   go <- chkGraphicsOpt()
 
   if (go == "base") {
@@ -71,7 +72,8 @@ plotLoadings <- function(spectra, pca, loads = c(1), ref = 1, ...) {
       xlab = spectra$unit[1], ylab = "",
       sub = list(
         label = pca$method,
-        fontface = "plain"),
+        fontface = "plain"
+      ),
       layout = c(1, length(loads) + 1),
       strip.left = TRUE, strip = FALSE, col = "black",
       scales = list(x = "same", y = "free"),
@@ -81,7 +83,8 @@ plotLoadings <- function(spectra, pca, loads = c(1), ref = 1, ...) {
         } else {
           lattice::panel.xyplot(..., type = type)
         }
-      }, ...)
+      }, ...
+    )
 
     plot(p)
   }
