@@ -72,7 +72,6 @@
 #' @importFrom utils browseURL
 #'
 plotSpectraJS <- function(spectra, which = NULL, browser = NULL, minify = TRUE) {
-
   # This is the R front end controlling everything
 
   .chkArgs(mode = 11L)
@@ -84,18 +83,13 @@ plotSpectraJS <- function(spectra, which = NULL, browser = NULL, minify = TRUE)
     spectra <- removeSample(spectra, rem.sam = which2)
   }
 
-  if (!requireNamespace("jsonlite", quietly = TRUE)) {
-    stop("You need install package jsonlite to use this function")
-  }
-
-  # Check to see if spectra$freq is increasing - if not, the scales will be inverted
-  # Silently reverse things
-  if (is.unsorted(spectra$freq)) {
-    spectra$freq <- rev(spectra$freq)
-    spectra$data <- spectra$data[, ncol(spectra$data):1]
-  }
-
-  if (requireNamespace("jsonlite", quietly = TRUE)) {
+  if (.chkReqPkgs("jsonlite")) {
+    # Check to see if spectra$freq is increasing - if not, the scales will be inverted
+    # Silently reverse things
+    if (is.unsorted(spectra$freq)) {
+      spectra$freq <- rev(spectra$freq)
+      spectra$data <- spectra$data[, ncol(spectra$data):1]
+    }
 
     # Break the pieces of the Spectra object out into
     # separate JSON entities
@@ -169,15 +163,11 @@ plotSpectraJS <- function(spectra, which = NULL, browser = NULL, minify = TRUE)
     )
 
     if (minify) {
-      if (requireNamespace("js", quietly = TRUE)) {
+      if (.chkReqPkgs("js")) {
         text <- js::uglify_optimize(text, unused = FALSE)
       }
-      if (!requireNamespace("js", quietly = TRUE)) {
-        stop("You need install package js to minify the JavaScript code")
-      }
     }
 
-
     writeLines(text, sep = "\n", con = file.path(td, "pS.js"))
 
     # Open the file in a browser
